pyx: Generate PostScript, PDF, and SVG files in Python
======================================================

Description
-----------

Python package for the generation of PostScript, PDF, and SVG files

https://pypi.python.org/pypi/PyX
